"""这是nester.py模块，提供函数用来打印循环嵌套列表"""
def print_lol(the_list,level):
    """这个函数打印一个包含嵌套列表的列表，并tab缩进"""
    for each in the_list:
        if isinstance(each,list):
            print_lol(each,level+1)
        else:
            for num in range(level):
                print("\t",end='')
            print(each)



from distutils.core import setup
setup(
    name = 'cindy_test',
    version = '1.0.0',
    py_modules = ['cindy_test'],
    author = 'cindy',
    author_email = 'zhengping.pin@gmail.com',
    description = 'A simple printer of nested list',
    )
